@@ -565,6 +565,18 @@ module Test
                      result.summary)
       end
 
+      def test_gc
+        test_case = Class.new(TestCase) do
+          def test_set_instance_variable
+            @variable = "anything"
+          end
+        end
+
+        test = test_case.new("test_set_instance_variable")
+        test.run(TestResult.new) {}
+        assert_nil(test.instance_variable_get(:@variable))
+      end
+
       private
       def check(message, passed)
         add_assertion
@@ -1051,6 +1063,7 @@ module Test
                   self.class.called << :test2_parent
                 end
               end
+              @parent_test_case.called.clear
 
               @child_test_case = Class.new(@parent_test_case) do
                 class << self
@@ -1079,6 +1092,7 @@ module Test
                   self.class.called << :test2_child
                 end
               end
+              @child_test_case.called.clear
             end
 
             def teardown
